@@ -91,7 +91,7 @@ Perform Levenberg-Marquardt least-squares minimization, based on MINPACK-1.
 
         def myfunct(p, fjac=None, x=None, y=None, err=None)
                 # Parameter values are passed in "p"
-                # If fjac==None then partial derivatives should not
+                # If fjac is None then partial derivatives should not
                 # computed.  It will always be None if MPFIT is called with default
                 # flag.
                 model = F(x, p)
@@ -129,11 +129,11 @@ Perform Levenberg-Marquardt least-squares minimization, based on MINPACK-1.
         AUTODERIVATIVE=0 is not necessary.
 
         If AUTODERIVATIVE=0 is used then the user function must check the parameter
-        FJAC, and if FJAC!=None then return the partial derivative array in the
+        FJAC, and if FJAC is not None then return the partial derivative array in the
         return list.
         def myfunct(p, fjac=None, x=None, y=None, err=None)
                 # Parameter values are passed in "p"
-                # If FJAC!=None then partial derivatives must be comptuer.
+                # If FJAC is not None then partial derivatives must be comptuer.
                 # FJAC contains an array of len(p), where each entry
                 # is 1 if that parameter is free and 0 if it is fixed.
                 model = F(x, p)
@@ -859,41 +859,42 @@ e.g. mpfit.status, mpfit.errmsg, mpfit.params, npfit.niter, mpfit.covar.
         self.machar = machar(double=1)
         machep = self.machar.machep
 
-        if (fcn==None):
+        if fcn is None:
             self.errmsg = "Usage: parms = mpfit('myfunt', ... )"
             return
 
-        if (iterfunct == 'default'): iterfunct = self.defiter
+        if iterfunct == 'default':
+            iterfunct = self.defiter
 
         ## Parameter damping doesn't work when user is providing their own
         ## gradients.
-        if (self.damp != 0) and (autoderivative == 0):
+        if self.damp != 0 and autoderivative == 0:
             self.errmsg =  'ERROR: keywords DAMP and AUTODERIVATIVE are mutually exclusive'
             return
 
         ## Parameters can either be stored in parinfo, or x. x takes precedence if it exists
-        if (xall == None) and (parinfo == None):
+        if xall is None and parinfo is None:
             self.errmsg = 'ERROR: must pass parameters in P or PARINFO'
             return
 
         ## Be sure that PARINFO is of the right type
-        if (parinfo != None):
+        if parinfo is not None:
             if (type(parinfo) != list):
                 self.errmsg = 'ERROR: PARINFO must be a list of dictionaries.'
                 return
             else:
-                if (type(parinfo[0]) != dict):
+                if type(parinfo[0]) != dict:
                     self.errmsg = 'ERROR: PARINFO must be a list of dictionaries.'
                     return
-            if ((xall != None) and (len(xall) != len(parinfo))):
+            if xall is not None and len(xall) != len(parinfo):
                 self.errmsg = 'ERROR: number of elements in PARINFO and P must agree'
                 return
 
         ## If the parameters were not specified at the command line, then
         ## extract them from PARINFO
-        if (xall == None):
+        if xall is None:
             xall = self.parinfo(parinfo, 'value')
-            if (xall == None):
+            if xall is None:
                 self.errmsg = 'ERROR: either P or PARINFO(*)["value"] must be supplied.'
                 return
 
@@ -956,7 +957,7 @@ e.g. mpfit.status, mpfit.errmsg, mpfit.params, npfit.niter, mpfit.covar.
         limited = self.parinfo(parinfo, 'limited', default=[0,0], n=npar)
         limits = self.parinfo(parinfo, 'limits', default=[0.,0.], n=npar)
 
-        if (limited != None) and (limits != None):
+        if limited is not None and limits is not None:
             ## Error checking on limits in parinfo
             wh = numpy.nonzero((limited[:,0] & (xall < limits[:,0])) |
                                                                     (limited[:,1] & (xall > limits[:,1])))
@@ -1029,9 +1030,10 @@ e.g. mpfit.status, mpfit.errmsg, mpfit.params, npfit.niter, mpfit.covar.
 
             ## If requested, call fcn to enable printing of iterates
             numpy.put(self.params, ifree, x)
-            if (self.qanytied): self.params = self.tie(self.params, ptied)
+            if self.qanytied:
+                self.params = self.tie(self.params, ptied)
 
-            if (nprint > 0) and (iterfunct != None):
+            if nprint > 0 and iterfunct is not None:
                 if (((self.niter-1) % nprint) == 0):
                     mperr = 0
                     xnew0 = self.params.copy()
@@ -1040,7 +1042,8 @@ e.g. mpfit.status, mpfit.errmsg, mpfit.params, npfit.niter, mpfit.covar.
                     status = iterfunct(fcn, self.params, self.niter, self.fnorm**2,
                             functkw=functkw, parinfo=parinfo, quiet=quiet,
                             dof=dof, **iterkw)
-                    if (status != None): self.status = status
+                    if status is not None:
+                        self.status = status
 
                     ## Check for user termination
                     if (self.status < 0):
@@ -1060,24 +1063,24 @@ e.g. mpfit.status, mpfit.errmsg, mpfit.params, npfit.niter, mpfit.covar.
                                                     epsfcn=epsfcn,
                                                     autoderivative=autoderivative, dstep=dstep,
                                                     functkw=functkw, ifree=ifree, xall=self.params)
-            if (fjac == None):
+            if fjac is None:
                 self.errmsg = 'WARNING: premature termination by FDJAC2'
                 return
 
             ## Determine if any of the parameters are pegged at the limits
-            if (qanylim):
+            if qanylim:
                 catch_msg = 'zeroing derivatives of pegged parameters'
                 whlpeg = (numpy.nonzero(qllim & (x == llim)))[0]
                 nlpeg = len(whlpeg)
                 whupeg = (numpy.nonzero(qulim & (x == ulim)) )[0]
                 nupeg = len(whupeg)
                 ## See if any "pegged" values should keep their derivatives
-                if (nlpeg > 0):
+                if nlpeg > 0:
                     ## Total derivative of sum wrt lower pegged parameters
                     for i in range(nlpeg):
                         sum = numpy.sum(fvec * fjac[:,whlpeg[i]])
                         if (sum > 0): fjac[:,whlpeg[i]] = 0
-                if (nupeg > 0):
+                if nupeg > 0:
                     ## Total derivative of sum wrt upper pegged parameters
                     for i in range(nupeg):
                         sum = numpy.sum(fvec * fjac[:,whupeg[i]])
@@ -1089,8 +1092,8 @@ e.g. mpfit.status, mpfit.errmsg, mpfit.params, npfit.niter, mpfit.covar.
             ## On the first iteration if "diag" is unspecified, scale
             ## according to the norms of the columns of the initial jacobian
             catch_msg = 'rescaling diagonal elements'
-            if (self.niter == 1):
-                if ((rescale==0) or (len(diag) < n)):
+            if self.niter == 1:
+                if rescale == 0 or len(diag) < n:
                     diag = wa2.copy()
                     wh = (numpy.nonzero(diag == 0) )[0]
                     numpy.put(diag, wh, 1.)
@@ -1310,26 +1313,30 @@ e.g. mpfit.status, mpfit.errmsg, mpfit.params, npfit.niter, mpfit.covar.
         ## Termination, either normal or user imposed.
         if (len(self.params) == 0):
             return
-        if (nfree == 0): self.params = xall.copy()
-        else: numpy.put(self.params, ifree, x)
-        if (nprint > 0) and (self.status > 0):
+
+        if (nfree == 0):
+            self.params = xall.copy()
+        else:
+            numpy.put(self.params, ifree, x)
+
+        if nprint > 0 and self.status > 0:
             catch_msg = 'calling ' + str(fcn)
             [status, fvec] = self.call(fcn, self.params, functkw)
             catch_msg = 'in the termination phase'
             self.fnorm = self.enorm(fvec)
 
-        if ((self.fnorm != None) and (fnorm1 != None)):
+        if self.fnorm is not None and fnorm1 is not None:
             self.fnorm = max([self.fnorm, fnorm1])
             self.fnorm = self.fnorm**2.
 
         self.covar = None
         self.perror = None
         ## (very carefully) set the covariance matrix COVAR
-        if ((self.status > 0) and (nocovar==0) and (n != None)
-                                                and (fjac != None) and (ipvt != None)):
+        if (self.status > 0 and nocovar == 0 and n is not None
+            and fjac is not None and ipvt is not None):
             sz = numpy.shape(fjac)
-            if ((n > 0) and (sz[0] >= n) and (sz[1] >= n)
-                            and (len(ipvt) >= n)):
+
+            if (n > 0 and sz[0] >= n and sz[1] >= n and len(ipvt) >= n):
                 catch_msg = 'computing the covariance matrix'
                 cv = self.calc_covar(fjac[0:n,0:n], ipvt[0:n])
                 cv.shape = [n, n]
@@ -1343,6 +1350,7 @@ e.g. mpfit.status, mpfit.errmsg, mpfit.params, npfit.niter, mpfit.covar.
                     indices = ifree+ifree[i]*nn
                     numpy.put(self.covar, indices, cv[:,i])
                     #numpy.put(self.covar, i, cv[:,i])
+
                 ## Compute errors in parameters
                 catch_msg = 'computing parameter errors'
                 self.perror = numpy.zeros(nn, numpy.float)
@@ -1356,12 +1364,15 @@ e.g. mpfit.status, mpfit.errmsg, mpfit.params, npfit.niter, mpfit.covar.
     ## Default procedure to be called every iteration.  It simply prints
     ## the parameter values.
     def defiter(self, fcn, x, iter, fnorm=None, functkw=None,
-                                                            quiet=0, iterstop=None, parinfo=None,
-                                                            format=None, pformat='%.10g', dof=1):
+                quiet=0, iterstop=None, parinfo=None,
+                format=None, pformat='%.10g', dof=1):
+        if self.debug:
+            print('Entering defiter...')
 
-        if (self.debug): print('Entering defiter...')
-        if (quiet): return
-        if (fnorm == None):
+        if quiet:
+            return
+
+        if fnorm is None:
             [status, fvec] = self.call(fcn, x, functkw)
             fnorm = self.enorm(fvec)**2
 
@@ -1369,17 +1380,20 @@ e.g. mpfit.status, mpfit.errmsg, mpfit.params, npfit.niter, mpfit.covar.
         nprint = len(x)
         print("Iter ", ('%6i' % iter),"   CHI-SQUARE = ",('%.10g' % fnorm)," DOF = ", ('%i' % dof))
         for i in range(nprint):
-            if (parinfo != None) and ('parname' in parinfo[i]):
+            if parinfo is not None and 'parname' in parinfo[i]:
                 p = '   ' + parinfo[i]['parname'] + ' = '
             else:
                 p = '   P' + str(i) + ' = '
-            if (parinfo != None) and ('mpprint' in parinfo[i]):
+
+            if parinfo is not None and 'mpprint' in parinfo[i]:
                 iprint = parinfo[i]['mpprint']
             else:
                 iprint = 1
-            if (iprint):
+
+            if iprint:
                 print(p + (pformat % x[i]) + '  ')
-        return(0)
+
+        return 0
 
     ##  DO_ITERSTOP:
     ##  if keyword_set(iterstop) then begin
@@ -1400,44 +1414,55 @@ e.g. mpfit.status, mpfit.errmsg, mpfit.params, npfit.niter, mpfit.covar.
 
     ## Procedure to parse the parameter values in PARINFO, which is a list of dictionaries
     def parinfo(self, parinfo=None, key='a', default=None, n=0):
-        if (self.debug): print('Entering parinfo...')
-        if (n == 0) and (parinfo != None): n = len(parinfo)
-        if (n == 0):
+        if self.debug:
+            print('Entering parinfo...')
+
+        if n == 0 and parinfo is not None:
+            n = len(parinfo)
+
+        if n == 0:
             values = default
             return(values)
 
         values = []
         for i in range(n):
-            if ((parinfo != None) and (key in parinfo[i])):
+            if parinfo is not None and key in parinfo[i]:
                 values.append(parinfo[i][key])
             else:
                 values.append(default)
 
         # Convert to numeric arrays if possible
         test = default
-        if (type(default) == list): test=default[0]
-        if (type(test) == int):
+        if type(default) == list: test=default[0]
+        if type(test) == int:
             values = numpy.asarray(values, dtype=numpy.int)
-        elif (type(test) == float):
+        elif type(test) == float:
             values = numpy.asarray(values, dtype=numpy.float)
+
         return(values)
 
 
     ## Call user function or procedure, with _EXTRA or not, with
     ## derivatives or not.
     def call(self, fcn, x, functkw, fjac=None):
-        if (self.debug): print('Entering call...')
-        if (self.qanytied): x = self.tie(x, self.ptied)
+        if self.debug:
+            print('Entering call...')
+
+        if self.qanytied:
+            x = self.tie(x, self.ptied)
+
         self.nfev = self.nfev + 1
-        if (fjac == None):
+
+        if fjac is None:
             [status, f] = fcn(x, fjac=fjac, **functkw)
 
-            if (self.damp > 0):
+            if self.damp > 0:
                 ## Apply the damping if requested.  This replaces the residuals
                 ## with their hyperbolic tangent.  Thus residuals larger than
                 ## DAMP are essentially clipped.
                 f = numpy.tanh(f/self.damp)
             return([status, f])
+
         else:
             return(fcn(x, fjac=fjac, **functkw))
 
@@ -1479,10 +1504,18 @@ e.g. mpfit.status, mpfit.errmsg, mpfit.params, npfit.niter, mpfit.covar.
 
         if (self.debug): print('Entering fdjac2...')
         machep = self.machar.machep
-        if epsfcn == None:  epsfcn = machep
-        if xall == None:    xall = x
-        if ifree == None:   ifree = numpy.arange(len(xall))
-        if step == None:    step = x * 0.
+        if epsfcn is None:
+            epsfcn = machep
+
+        if xall is None:
+            xall = x
+
+        if ifree is None:
+            ifree = numpy.arange(len(xall))
+
+        if step is None:
+            step = x * 0.
+
         nall = len(xall)
 
         eps = numpy.sqrt(max([epsfcn, machep]))
@@ -1516,7 +1549,7 @@ e.g. mpfit.status, mpfit.errmsg, mpfit.params, npfit.niter, mpfit.covar.
         h = eps * abs(x)
 
         ## if STEP is given, use that
-        if step != None:
+        if step is not None:
             stepi = numpy.take(step, ifree)
             wh = (numpy.nonzero(stepi > 0) )[0]
             if (len(wh) > 0): numpy.put(h, wh, numpy.take(stepi, wh))
@@ -2121,13 +2154,20 @@ e.g. mpfit.status, mpfit.errmsg, mpfit.params, npfit.niter, mpfit.covar.
 
     ## Procedure to tie one parameter to another.
     def tie(self, p, ptied=None):
-        if (self.debug): print('Entering tie...')
-        if (ptied == None): return
+        if self.debug:
+            print('Entering tie...')
+
+        if ptied is None:
+            return
+
         for i in range(len(ptied)):
-            if ptied[i] == '': continue
+            if ptied[i] == '':
+                continue
+
             cmd = 'p[' + str(i) + '] = ' + ptied[i]
             exec(cmd)
-        return(p)
+
+        return p
 
 
     #     Original FORTRAN documentation
@@ -2199,17 +2239,21 @@ e.g. mpfit.status, mpfit.errmsg, mpfit.params, npfit.niter, mpfit.covar.
 
     def calc_covar(self, rr, ipvt=None, tol=1.e-14):
 
-        if (self.debug): print('Entering calc_covar...')
+        if self.debug:
+            print('Entering calc_covar...')
+
         if numpy.rank(rr) != 2:
             print('ERROR: r must be a two-dimensional matrix')
             return(-1)
+
         s = numpy.shape(rr)
         n = s[0]
         if s[0] != s[1]:
             print('ERROR: r must be a square matrix')
             return(-1)
 
-        if (ipvt == None): ipvt = numpy.arange(n)
+        if ipvt is None:
+            ipvt = numpy.arange(n)
         r = rr.copy()
         r.shape = [n,n]
 
