@@ -210,7 +210,7 @@ def byteswap(input,output=None,clobber=True):
 
     _shape = _naxis[1:]
     _shape.reverse()
-    _code = fits.hdu.ImageHDU.NumCode[_bitpix]
+    _code = fits.BITPIX2DTYPE[_bitpix]
     _bscale = phdr.get('BSCALE', 1)
     _bzero = phdr.get('BZERO', 0)
     if phdr['DATATYPE'][:10] == 'UNSIGNED*2':
@@ -377,7 +377,7 @@ def byteswap(input,output=None,clobber=True):
 
     _shape = _naxis[1:]
     _shape.reverse()
-    _code = fits.hdu.ImageHDU.NumCode[_bitpix]
+    _code = fits.BITPIX2DTYPE[_bitpix]
     _bscale = phdr.get('BSCALE', 1)
     _bzero = phdr.get('BZERO', 0)
     if phdr['DATATYPE'][:10] == 'UNSIGNED*2':
@@ -544,14 +544,20 @@ def parse_path(f1, f2):
     else:
         list2 = [s.strip() for s in f2.split(",")]
 
-    if (list1 == [] or list2 == []):
-        str = ""
-        if (list1 == []): str += "Input files `%s` not usable/available. " % f1
-        if (list2 == []): str += "Input files `%s` not usable/available. " % f2
-        raise IOError(str)
+    if list1 == [] or list2 == []:
+        err_msg = ""
+        if list1 == []:
+            err_msg += "Input files `{:s}` not usable/available. ".format(f1)
+
+        if list2 == []:
+            err_msg += "Input files `{:s}` not usable/available. ".format(f2)
+
+        raise IOError(err_msg)
+
     else:
         return list1, list2
 
+
 #-------------------------------------------------------------------------------
 # special initialization when this is the main program
 
